# harborapi.models._models

These models have been generated from the official Harbor REST API [Swagger 2.0 Schema](https://github.com/goharbor/harbor/blob/main/api/v2.0/swagger.yaml) using [datamodel-code-generator](https://koxudaxi.github.io/datamodel-code-generator/) version 0.13.0.

::: harborapi.models._models
    options:
        show_if_no_docstring: true
        show_source: true
        show_bases: false
